@@ -37,7 +37,7 @@
 //system includes
 #include <stdlib.h>
 
-//QT includes
+//TQt includes
 #include <tqpopupmenu.h>
 #include <tqsplitter.h>
 #include <tqguardedptr.h>
@@ -46,7 +46,7 @@
 #include <tqlabel.h>
 #include <tqvbox.h>
 
-//KDE includes
+//TDE includes
 #include <tdeaboutdata.h>
 #include <tdeaccel.h>
 #include <tdeaction.h>
@@ -78,7 +78,7 @@ void BibleTime::initView() {
 	m_mainSplitter->setChildrenCollapsible(false);
 	setCentralWidget(m_mainSplitter);
 
-	m_leftPaneSplitter = new TQSplitter(Qt::Vertical, m_mainSplitter);
+	m_leftPaneSplitter = new TQSplitter(TQt::Vertical, m_mainSplitter);
 	m_leftPaneSplitter->setChildrenCollapsible(false);
 	
 	TQVBox* vBox = new TQVBox(m_leftPaneSplitter);
@@ -104,7 +104,7 @@ void BibleTime::initActions() {
 	TDEStartupLogo::setStatusMessage(i18n("Initializing menu- and toolbars") + TQString("..."));
 	TDEAction* action = 0;
 
-	action = KStdAction::quit(TQT_TQOBJECT(kapp), TQT_SLOT( quit() ), actionCollection());
+	action = KStdAction::quit(kapp, TQ_SLOT( quit() ), actionCollection());
 	action->setToolTip( CResMgr::mainMenu::file::quit::tooltip );
 
 	#if TDE_VERSION_MINOR < 1
@@ -115,7 +115,7 @@ void BibleTime::initActions() {
 	action = new TDEAction(i18n("Search in &open work(s)"),
 						 CResMgr::mainMenu::mainIndex::search::icon,
 						 CResMgr::mainMenu::mainIndex::search::accel,
-						 TQT_TQOBJECT(this), TQT_SLOT(slotSearchModules()), actionCollection(),
+						 this, TQ_SLOT(slotSearchModules()), actionCollection(),
 						 CResMgr::mainMenu::mainIndex::search::actionName
 						);
 	action->setToolTip( CResMgr::mainMenu::mainIndex::search::tooltip );
@@ -128,7 +128,7 @@ void BibleTime::initActions() {
 	action = new TDEAction(i18n("Search in standard &Bible"),
 						 CResMgr::mainMenu::mainIndex::searchdefaultbible::icon,
 						 CResMgr::mainMenu::mainIndex::searchdefaultbible::accel,
-						 TQT_TQOBJECT(this), TQT_SLOT(slotSearchDefaultBible()), actionCollection(),
+						 this, TQ_SLOT(slotSearchDefaultBible()), actionCollection(),
 						 CResMgr::mainMenu::mainIndex::searchdefaultbible::actionName
 						);
 	action->setToolTip( CResMgr::mainMenu::mainIndex::searchdefaultbible::tooltip );
@@ -138,7 +138,7 @@ void BibleTime::initActions() {
 	action->plugAccel( accel() );
 	#endif
 
-	m_viewToolbar_action = KStdAction::showToolbar(TQT_TQOBJECT(this), TQT_SLOT( slotToggleToolbar() ), actionCollection());
+	m_viewToolbar_action = KStdAction::showToolbar(this, TQ_SLOT( slotToggleToolbar() ), actionCollection());
 	m_viewToolbar_action->setToolTip( CResMgr::mainMenu::view::showToolBar::tooltip );
 
 	#if TDE_VERSION_MINOR < 1
@@ -150,7 +150,7 @@ void BibleTime::initActions() {
 	m_viewMainIndex_action = new TDEToggleAction(i18n("&Show bookshelf"),
 							 CResMgr::mainMenu::view::showMainIndex::icon,
 							 CResMgr::mainMenu::view::showMainIndex::accel,
-							 TQT_TQOBJECT(this), TQT_SLOT(slotToggleMainIndex()), actionCollection(),
+							 this, TQ_SLOT(slotToggleMainIndex()), actionCollection(),
 							 CResMgr::mainMenu::view::showMainIndex::actionName);
 	m_viewMainIndex_action->setToolTip( CResMgr::mainMenu::view::showMainIndex::tooltip );
 
@@ -162,7 +162,7 @@ void BibleTime::initActions() {
 	m_viewInfoDisplay_action = new TDEToggleAction(i18n("Show &mag"),
 							   CResMgr::mainMenu::view::showInfoDisplay::icon,
 							   CResMgr::mainMenu::view::showInfoDisplay::accel,
-							   TQT_TQOBJECT(this), TQT_SLOT(slotToggleInfoDisplay()), actionCollection(),
+							   this, TQ_SLOT(slotToggleInfoDisplay()), actionCollection(),
 							   CResMgr::mainMenu::view::showInfoDisplay::actionName);
 	m_viewMainIndex_action->setToolTip( CResMgr::mainMenu::view::showInfoDisplay::tooltip );
 
@@ -171,7 +171,7 @@ void BibleTime::initActions() {
 	m_viewInfoDisplay_action->plugAccel( accel() );
 	#endif
 
-	action = KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT( slotSettingsOptions() ), actionCollection());
+	action = KStdAction::preferences(this, TQ_SLOT( slotSettingsOptions() ), actionCollection());
 	action->setToolTip( CResMgr::mainMenu::settings::optionsDialog::tooltip );
 
 	#if TDE_VERSION_MINOR < 1
@@ -182,7 +182,7 @@ void BibleTime::initActions() {
 	action = new TDEAction(i18n("Bookshelf &Manager"),
 						 CResMgr::mainMenu::settings::swordSetupDialog::icon,
 						 CResMgr::mainMenu::settings::swordSetupDialog::accel,
-						 TQT_TQOBJECT(this), TQT_SLOT( slotSwordSetupDialog() ), actionCollection(),
+						 this, TQ_SLOT( slotSwordSetupDialog() ), actionCollection(),
 						 CResMgr::mainMenu::settings::swordSetupDialog::actionName
 						);
 	action->setToolTip( CResMgr::mainMenu::settings::swordSetupDialog::tooltip );
@@ -191,14 +191,14 @@ void BibleTime::initActions() {
 	action->plugAccel( accel() );
 	#endif
 
-	//delete help action if KDE created it
+	//delete help action if TDE created it
 	if ( actionCollection()->action( KStdAction::stdName(KStdAction::ConfigureToolbars) )) {
 		actionCollection()->remove
 		(actionCollection()->action(
 			 KStdAction::stdName(KStdAction::ConfigureToolbars))
 		);
 	}
-	action = KStdAction::configureToolbars(TQT_TQOBJECT(this), TQT_SLOT( slotSettingsToolbar() ), actionCollection());
+	action = KStdAction::configureToolbars(this, TQ_SLOT( slotSettingsToolbar() ), actionCollection());
 	action->setToolTip( CResMgr::mainMenu::settings::editToolBar::tooltip );
 	#if TDE_VERSION_MINOR < 1
 
@@ -214,7 +214,7 @@ void BibleTime::initActions() {
 	m_windowManualMode_action = new TDEToggleAction(i18n("&Manual mode"),
 								CResMgr::mainMenu::window::arrangementMode::manual::icon,
 								CResMgr::mainMenu::window::arrangementMode::manual::accel,
-								TQT_TQOBJECT(this), TQT_SLOT(slotManualArrangementMode()), actionCollection(),
+								this, TQ_SLOT(slotManualArrangementMode()), actionCollection(),
 								CResMgr::mainMenu::window::arrangementMode::manual::actionName
 												 );
 	m_windowManualMode_action->setToolTip(
@@ -231,7 +231,7 @@ void BibleTime::initActions() {
 	m_windowAutoTileVertical_action = new TDEToggleAction(i18n("Auto-tile &vertically"),
 									  CResMgr::mainMenu::window::arrangementMode::autoTileVertical::icon,
 									  CResMgr::mainMenu::window::arrangementMode::autoTileVertical::accel,
-									  TQT_TQOBJECT(this), TQT_SLOT(slotAutoTileVertical()), actionCollection(),
+									  this, TQ_SLOT(slotAutoTileVertical()), actionCollection(),
 									  CResMgr::mainMenu::window::arrangementMode::autoTileVertical::actionName
 													   );
 	m_windowAutoTileVertical_action->setToolTip(
@@ -248,7 +248,7 @@ void BibleTime::initActions() {
 	m_windowAutoTileHorizontal_action = new TDEToggleAction(i18n("Auto-tile &horizontally"),
 										CResMgr::mainMenu::window::arrangementMode::autoTileHorizontal::icon,
 										CResMgr::mainMenu::window::arrangementMode::autoTileHorizontal::accel,
-										TQT_TQOBJECT(this), TQT_SLOT(slotAutoTileHorizontal()), actionCollection(),
+										this, TQ_SLOT(slotAutoTileHorizontal()), actionCollection(),
 										CResMgr::mainMenu::window::arrangementMode::autoTileHorizontal::actionName
 														 );
 	m_windowAutoTileHorizontal_action->setToolTip(
@@ -265,7 +265,7 @@ void BibleTime::initActions() {
 	m_windowAutoCascade_action  = new TDEToggleAction(i18n("Auto-&cascade"),
 								  CResMgr::mainMenu::window::arrangementMode::autoCascade::icon,
 								  CResMgr::mainMenu::window::arrangementMode::autoCascade::accel,
-								  TQT_TQOBJECT(this), TQT_SLOT(slotAutoCascade()), actionCollection(),
+								  this, TQ_SLOT(slotAutoCascade()), actionCollection(),
 								  CResMgr::mainMenu::window::arrangementMode::autoCascade::actionName
 												   );
 	m_windowAutoCascade_action->setToolTip(
@@ -281,7 +281,7 @@ void BibleTime::initActions() {
 	m_windowCascade_action = new TDEAction(i18n("&Cascade"),
 										 CResMgr::mainMenu::window::cascade::icon,
 										 CResMgr::mainMenu::window::cascade::accel,
-										 TQT_TQOBJECT(this), TQT_SLOT(slotCascade()), actionCollection(),
+										 this, TQ_SLOT(slotCascade()), actionCollection(),
 										 CResMgr::mainMenu::window::cascade::actionName
 										);
 	m_windowCascade_action->setToolTip( CResMgr::mainMenu::window::cascade::tooltip );
@@ -295,7 +295,7 @@ void BibleTime::initActions() {
 	m_windowTileVertical_action = new TDEAction(i18n("Tile &vertically"),
 								  CResMgr::mainMenu::window::tileVertical::icon,
 								  CResMgr::mainMenu::window::tileVertical::accel,
-								  TQT_TQOBJECT(this), TQT_SLOT(slotTileVertical()), actionCollection(),
+								  this, TQ_SLOT(slotTileVertical()), actionCollection(),
 								  CResMgr::mainMenu::window::tileVertical::actionName
 											 );
 	m_windowTileVertical_action->setToolTip( CResMgr::mainMenu::window::tileVertical::tooltip );
@@ -307,7 +307,7 @@ void BibleTime::initActions() {
 	m_windowTileHorizontal_action = new TDEAction(i18n("Tile &horizontally"),
 									CResMgr::mainMenu::window::tileHorizontal::icon,
 									CResMgr::mainMenu::window::tileHorizontal::accel,
-									TQT_TQOBJECT(this), TQT_SLOT(slotTileHorizontal()), actionCollection(),
+									this, TQ_SLOT(slotTileHorizontal()), actionCollection(),
 									CResMgr::mainMenu::window::tileHorizontal::actionName
 											   );
 	m_windowTileHorizontal_action->setToolTip( CResMgr::mainMenu::window::tileHorizontal::tooltip );
@@ -321,7 +321,7 @@ void BibleTime::initActions() {
 	m_windowCloseAll_action = new TDEAction(i18n("Cl&ose all"),
 										  CResMgr::mainMenu::window::closeAll::icon,
 										  CResMgr::mainMenu::window::closeAll::accel,
-										  TQT_TQOBJECT(m_mdi), TQT_SLOT(deleteAll()), actionCollection(),
+										  m_mdi, TQ_SLOT(deleteAll()), actionCollection(),
 										  CResMgr::mainMenu::window::closeAll::actionName
 										 );
 	m_windowCloseAll_action->setToolTip( CResMgr::mainMenu::window::closeAll::tooltip );
@@ -347,7 +347,7 @@ void BibleTime::initActions() {
 	m_windowSaveToNewProfile_action = new TDEAction(i18n("Save as &new session"),
 									  CResMgr::mainMenu::window::saveToNewProfile::icon,
 									  CResMgr::mainMenu::window::saveToNewProfile::accel,
-									  TQT_TQOBJECT(this), TQT_SLOT(saveToNewProfile()), actionCollection(),
+									  this, TQ_SLOT(saveToNewProfile()), actionCollection(),
 									  CResMgr::mainMenu::window::saveToNewProfile::actionName
 												 );
 	m_windowSaveToNewProfile_action->setToolTip( CResMgr::mainMenu::window::saveToNewProfile::tooltip );
@@ -384,7 +384,7 @@ void BibleTime::initActions() {
 	m_windowFullscreen_action = new TDEToggleAction(i18n("&Fullscreen mode"),
 								CResMgr::mainMenu::window::showFullscreen::icon,
 								CResMgr::mainMenu::window::showFullscreen::accel,
-								TQT_TQOBJECT(this), TQT_SLOT(toggleFullscreen()), actionCollection(),
+								this, TQ_SLOT(toggleFullscreen()), actionCollection(),
 								CResMgr::mainMenu::window::showFullscreen::actionName
 												 );
 	m_windowFullscreen_action->setToolTip( CResMgr::mainMenu::window::showFullscreen::tooltip );
@@ -399,13 +399,13 @@ void BibleTime::initActions() {
 	TDEPopupMenu* savePopup = m_windowSaveProfile_action->popupMenu();
 	TDEPopupMenu* deletePopup = m_windowDeleteProfile_action->popupMenu();
 
-	connect(loadPopup, TQT_SIGNAL(activated(int)), TQT_SLOT(loadProfile(int)));
-	connect(savePopup, TQT_SIGNAL(activated(int)), TQT_SLOT(saveProfile(int)));
-	connect(deletePopup, TQT_SIGNAL(activated(int)), TQT_SLOT(deleteProfile(int)));
+	connect(loadPopup, TQ_SIGNAL(activated(int)), TQ_SLOT(loadProfile(int)));
+	connect(savePopup, TQ_SIGNAL(activated(int)), TQ_SLOT(saveProfile(int)));
+	connect(deletePopup, TQ_SIGNAL(activated(int)), TQ_SLOT(deleteProfile(int)));
 
 	refreshProfileMenus();
 
-	if ( actionCollection()->action( KStdAction::stdName(KStdAction::HelpContents) )) {  //delete help action if KDE created it
+	if ( actionCollection()->action( KStdAction::stdName(KStdAction::HelpContents) )) {  //delete help action if TDE created it
 		actionCollection()->remove
 		(actionCollection()->action(KStdAction::stdName(KStdAction::HelpContents)) );
 	}
@@ -413,7 +413,7 @@ void BibleTime::initActions() {
 	action = new TDEAction(i18n("&Handbook"),
 						 CResMgr::mainMenu::help::handbook::icon,
 						 CResMgr::mainMenu::help::handbook::accel,
-						 TQT_TQOBJECT(this), TQT_SLOT(openOnlineHelp_Handbook()), actionCollection(),
+						 this, TQ_SLOT(openOnlineHelp_Handbook()), actionCollection(),
 						 CResMgr::mainMenu::help::handbook::actionName
 						);
 	action->setToolTip( CResMgr::mainMenu::help::handbook::tooltip );
@@ -426,7 +426,7 @@ void BibleTime::initActions() {
 	action = new TDEAction(i18n("&Bible Study Howto"),
 						 CResMgr::mainMenu::help::bibleStudyHowTo::icon,
 						 CResMgr::mainMenu::help::bibleStudyHowTo::accel,
-						 TQT_TQOBJECT(this), TQT_SLOT(openOnlineHelp_Howto()), actionCollection(),
+						 this, TQ_SLOT(openOnlineHelp_Howto()), actionCollection(),
 						 CResMgr::mainMenu::help::bibleStudyHowTo::actionName
 						);
 	action->setToolTip( CResMgr::mainMenu::help::bibleStudyHowTo::tooltip );
@@ -436,18 +436,18 @@ void BibleTime::initActions() {
 	action->plugAccel( accel() );
 	#endif
 
-	if ( actionCollection()->action( KStdAction::stdName( KStdAction::WhatsThis ) ) ) {  //delete "What's this" action if KDE created it already
+	if ( actionCollection()->action( KStdAction::stdName( KStdAction::WhatsThis ) ) ) {  //delete "What's this" action if TDE created it already
 		TDEAction* action = actionCollection()->action(KStdAction::stdName( KStdAction::WhatsThis ));
 		actionCollection()->remove
 		( action );
 	}
 
 
-	if ( actionCollection()->action( KStdAction::stdName( KStdAction::ReportBug ) ) ) { //delete Report Bug action if KDE created it
+	if ( actionCollection()->action( KStdAction::stdName( KStdAction::ReportBug ) ) ) { //delete Report Bug action if TDE created it
 		actionCollection()->remove
 		(actionCollection()->action(KStdAction::stdName( KStdAction::ReportBug )));
 	}
-	action = KStdAction::reportBug(m_helpMenu, TQT_SLOT(reportBug()), actionCollection());
+	action = KStdAction::reportBug(m_helpMenu, TQ_SLOT(reportBug()), actionCollection());
 	action->setToolTip(CResMgr::mainMenu::help::bugreport::tooltip);
 	#if TDE_VERSION_MINOR < 1
 
@@ -457,7 +457,7 @@ void BibleTime::initActions() {
 	action = new TDEAction(i18n("&Daily tip"),
 						 CResMgr::mainMenu::help::dailyTip::icon,
 						 CResMgr::mainMenu::help::dailyTip::accel,
-						 TQT_TQOBJECT(this), TQT_SLOT(slotHelpTipOfDay()), actionCollection(),
+						 this, TQ_SLOT(slotHelpTipOfDay()), actionCollection(),
 						 CResMgr::mainMenu::help::dailyTip::actionName
 						);
 	action->setToolTip(CResMgr::mainMenu::help::dailyTip::tooltip);
@@ -466,19 +466,19 @@ void BibleTime::initActions() {
 	action->plugAccel( accel() );
 	#endif
 
-	if ( actionCollection()->action( KStdAction::stdName( KStdAction::AboutApp ) ) ) {  //delete About KDE action if KDE created it
+	if ( actionCollection()->action( KStdAction::stdName( KStdAction::AboutApp ) ) ) {  //delete About TDE action if TDE created it
 		actionCollection()->remove
 		(actionCollection()->action(KStdAction::stdName( KStdAction::AboutApp )));
 	}
-	action = KStdAction::aboutApp(m_helpMenu, TQT_SLOT(aboutApplication()), actionCollection());
+	action = KStdAction::aboutApp(m_helpMenu, TQ_SLOT(aboutApplication()), actionCollection());
 	action->setToolTip(CResMgr::mainMenu::help::aboutBibleTime::tooltip);
 
-	//delete About KDE action if KDE created it already
-	if ( actionCollection()->action( KStdAction::stdName( KStdAction::AboutKDE ) ) ) {  //delete About KDE action if KDE created it
+	//delete About TDE action if TDE created it already
+	if ( actionCollection()->action( KStdAction::stdName( KStdAction::AboutKDE ) ) ) {  //delete About TDE action if TDE created it
 		actionCollection()->remove
 		(actionCollection()->action(KStdAction::stdName( KStdAction::AboutKDE )));
 	}
-	action = KStdAction::aboutKDE(m_helpMenu, TQT_SLOT(aboutKDE()), actionCollection());
+	action = KStdAction::aboutKDE(m_helpMenu, TQ_SLOT(aboutKDE()), actionCollection());
 	action->setToolTip(CResMgr::mainMenu::help::aboutKDE::tooltip);
 }
 
@@ -488,17 +488,17 @@ void BibleTime::initMenubar() {
 	m_windowMenu = dynamic_cast<TQPopupMenu*>(m_windowCloseAll_action->container(0));
 }
 
-/** Initializes the TQT_SIGNAL / TQT_SLOT connections */
+/** Initializes the signal / slot connections */
 void BibleTime::initConnections() {
-	connect(m_mdi, TQT_SIGNAL(sigSetToplevelCaption(const TQString&)),
-			this, TQT_SLOT(setPlainCaption(const TQString&)));
-	connect(m_mdi, TQT_SIGNAL(createReadDisplayWindow(ListCSwordModuleInfo, const TQString&)),
-			this, TQT_SLOT(createReadDisplayWindow(ListCSwordModuleInfo, const TQString&)));
+	connect(m_mdi, TQ_SIGNAL(sigSetToplevelCaption(const TQString&)),
+			this, TQ_SLOT(setPlainCaption(const TQString&)));
+	connect(m_mdi, TQ_SIGNAL(createReadDisplayWindow(ListCSwordModuleInfo, const TQString&)),
+			this, TQ_SLOT(createReadDisplayWindow(ListCSwordModuleInfo, const TQString&)));
 
 	Q_ASSERT(m_windowMenu);
 	if (m_windowMenu) {
-		connect(m_windowMenu, TQT_SIGNAL(aboutToShow()),
-				this, TQT_SLOT(slotWindowMenuAboutToShow()));
+		connect(m_windowMenu, TQ_SIGNAL(aboutToShow()),
+				this, TQ_SLOT(slotWindowMenuAboutToShow()));
 	}
 	else {
 		tqWarning("Main window: can't find window menu");
@@ -506,14 +506,14 @@ void BibleTime::initConnections() {
 
 
 	connect(
-		m_mainIndex, TQT_SIGNAL(createReadDisplayWindow(ListCSwordModuleInfo, const TQString&)),
-		this, TQT_SLOT(createReadDisplayWindow(ListCSwordModuleInfo,const TQString&))
+		m_mainIndex, TQ_SIGNAL(createReadDisplayWindow(ListCSwordModuleInfo, const TQString&)),
+		this, TQ_SLOT(createReadDisplayWindow(ListCSwordModuleInfo,const TQString&))
 	);
 	connect(
-		m_mainIndex, TQT_SIGNAL(createWriteDisplayWindow(CSwordModuleInfo*, const TQString&, const CDisplayWindow::WriteWindowType&)),
-		this, TQT_SLOT(createWriteDisplayWindow(CSwordModuleInfo*,const TQString&, const CDisplayWindow::WriteWindowType&))
+		m_mainIndex, TQ_SIGNAL(createWriteDisplayWindow(CSwordModuleInfo*, const TQString&, const CDisplayWindow::WriteWindowType&)),
+		this, TQ_SLOT(createWriteDisplayWindow(CSwordModuleInfo*,const TQString&, const CDisplayWindow::WriteWindowType&))
 	);
-	connect(m_mainIndex, TQT_SIGNAL(signalSwordSetupChanged()), this, TQT_SLOT(slotSwordSetupChanged()));
+	connect(m_mainIndex, TQ_SIGNAL(signalSwordSetupChanged()), this, TQ_SLOT(slotSwordSetupChanged()));
 }
 
 /** Initializes the backend */
@@ -580,8 +580,8 @@ void BibleTime::applyProfileSettings( CProfile* p ) {
 	Q_ASSERT(p);
 	if (!p) return;
 
-	if (m_initialized) { //on startup KDE sets the main geometry
-		//see polish(), where m_initialized is set and the KDE methods are called for window resize
+	if (m_initialized) { //on startup TDE sets the main geometry
+		//see polish(), where m_initialized is set and the TDE methods are called for window resize
 		
 		//first Main Window state
 		m_windowFullscreen_action->setChecked( p->fullscreen() );  //set the fullscreen button state
