@@ -29,7 +29,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-//QT includes
+//TQt includes
 #include <tqhbox.h>
 #include <tqlayout.h>
 #include <tqvbox.h>
@@ -47,22 +47,22 @@
 #include <tqinputdialog.h>
 #include <tqdir.h>
 
-//KDE includes
+//TDE includes
 #include <kapp.h>
-#include <klocale.h>
-#include <kglobal.h>
+#include <tdelocale.h>
+#include <tdeglobal.h>
 #include <kstandarddirs.h>
 #include <kkeydialog.h>
-#include <khtml_part.h>
-#include <khtmlview.h>
+#include <tdehtml_part.h>
+#include <tdehtmlview.h>
 #include <kiconloader.h>
 #include <ktabctl.h>
 #include <kapp.h>
-#include <klistbox.h>
+#include <tdelistbox.h>
 #include <kkeydialog.h>
-#include <kaction.h>
-#include <kconfigbase.h>
-#include <kconfig.h>
+#include <tdeaction.h>
+#include <tdeconfigbase.h>
+#include <tdeconfig.h>
 
 //Sword includes
 #include <localemgr.h>
@@ -71,7 +71,7 @@
 using std::string;
 using std::list;
 
-COptionsDialog::COptionsDialog(TQWidget *parent, const char *name, KActionCollection* actionCollection )
+COptionsDialog::COptionsDialog(TQWidget *parent, const char *name, TDEActionCollection* actionCollection )
 : KDialogBase(IconList, i18n("Configure BibleTime"), Ok | Cancel | Apply, Ok, parent, name, true, true, TQString(), TQString(), TQString()) {
 
 	m_settings.keys.application.actionCollection = actionCollection;
@@ -176,8 +176,8 @@ void COptionsDialog::initDisplay() {
 	TQHBoxLayout* hboxlayout = new TQHBoxLayout();
 
 	m_settings.displayStyle.styleChooser = new TQComboBox( page ); //create first to enable buddy for label
-	connect( m_settings.displayStyle.styleChooser, TQT_SIGNAL( activated( int ) ),
-			 this, TQT_SLOT( updateStylePreview() ) );
+	connect( m_settings.displayStyle.styleChooser, TQ_SIGNAL( activated( int ) ),
+			 this, TQ_SLOT( updateStylePreview() ) );
 
 	hboxlayout->addWidget(
 		new TQLabel(m_settings.displayStyle.styleChooser, i18n("Available display styles:"), page)
@@ -186,7 +186,7 @@ void COptionsDialog::initDisplay() {
 	hboxlayout->addStretch();
 	layout->addLayout( hboxlayout );
 
-	m_settings.displayStyle.stylePreview = new KHTMLPart(page);
+	m_settings.displayStyle.stylePreview = new TDEHTMLPart(page);
 	layout->addWidget(
 		new TQLabel(
 			m_settings.displayStyle.stylePreview->view(),
@@ -243,7 +243,7 @@ void COptionsDialog::initLanguages() {
 		//   locales.push_back(SWBuf("en_US"));
 
 		for (list<sword::SWBuf>::const_iterator it = locales.begin(); it != locales.end(); it++) {
-			//    qWarning("working on %s", (*it).c_str());
+			//    tqWarning("working on %s", (*it).c_str());
 			const CLanguageMgr::Language* const l = CPointers::languageMgr()->languageForAbbrev(
 														sword::LocaleMgr::getSystemLocaleMgr()->getLocale((*it).c_str())->getName()
 													);
@@ -335,18 +335,18 @@ void COptionsDialog::initLanguages() {
 		}
 
 		m_settings.fonts.useOwnFontBox = new TQCheckBox(i18n("Use custom font"), page, "font checkbox");
-		connect(m_settings.fonts.useOwnFontBox, TQT_SIGNAL(toggled(bool)), TQT_SLOT(useOwnFontClicked(bool)));
+		connect(m_settings.fonts.useOwnFontBox, TQ_SIGNAL(toggled(bool)), TQ_SLOT(useOwnFontClicked(bool)));
 		hLayout->addWidget(m_settings.fonts.useOwnFontBox);
 
 		layout->addLayout(hLayout);
 		//#warning TODO: remember the last selected font and jump there.
 
-		m_settings.fonts.fontChooser = new KFontChooser(page, "fonts", false, TQStringList(), true, 5);
+		m_settings.fonts.fontChooser = new TDEFontChooser(page, "fonts", false, TQStringList(), true, 5);
 		m_settings.fonts.fontChooser->setSampleText(i18n("The quick brown fox jumps over the lazy dog."));
 		layout->addWidget(m_settings.fonts.fontChooser);
 
-		connect(m_settings.fonts.fontChooser, TQT_SIGNAL(fontSelected(const TQFont&)), TQT_SLOT(newDisplayWindowFontSelected(const TQFont&)));
-		connect(m_settings.fonts.usage, TQT_SIGNAL(activated(const TQString&)), TQT_SLOT(newDisplayWindowFontAreaSelected(const TQString&)));
+		connect(m_settings.fonts.fontChooser, TQ_SIGNAL(fontSelected(const TQFont&)), TQ_SLOT(newDisplayWindowFontSelected(const TQFont&)));
+		connect(m_settings.fonts.usage, TQ_SIGNAL(activated(const TQString&)), TQ_SLOT(newDisplayWindowFontAreaSelected(const TQString&)));
 
 		m_settings.fonts.fontChooser->setFont( m_settings.fonts.fontMap[m_settings.fonts.usage->currentText()].second );
 		useOwnFontClicked( m_settings.fonts.fontMap[m_settings.fonts.usage->currentText()].first );
@@ -369,8 +369,8 @@ void COptionsDialog::initAccelerators() {
 	TQLabel* label = new TQLabel(i18n("Choose type:"), hbox);
 	m_settings.keys.typeChooser = new TQComboBox(hbox);
 	connect(
-		m_settings.keys.typeChooser, TQT_SIGNAL(activated(const TQString&)),
-		TQT_SLOT(slotKeyChooserTypeChanged(const TQString&))
+		m_settings.keys.typeChooser, TQ_SIGNAL(activated(const TQString&)),
+		TQ_SLOT(slotKeyChooserTypeChanged(const TQString&))
 	);
 	TQLabel* dummy = new TQLabel( hbox ); // empty label for stretch
 
@@ -407,7 +407,7 @@ void COptionsDialog::initAccelerators() {
 			);
 
 	// ----- All display windows ------ //
-	m_settings.keys.general.actionCollection = new KActionCollection(this, "displayActions", 0);
+	m_settings.keys.general.actionCollection = new TDEActionCollection(this, "displayActions", 0);
 	CDisplayWindow::insertKeyboardActions( m_settings.keys.general.actionCollection);
 	CBTConfig::setupAccelSettings(
 		CBTConfig::allWindows,
@@ -419,7 +419,7 @@ void COptionsDialog::initAccelerators() {
 										 );
 
 	// ----- Bible windows ------ //
-	m_settings.keys.bible.actionCollection = new KActionCollection(this, "bibleActions", 0);
+	m_settings.keys.bible.actionCollection = new TDEActionCollection(this, "bibleActions", 0);
 	CBibleReadWindow::insertKeyboardActions( m_settings.keys.bible.actionCollection);
 	CBTConfig::setupAccelSettings(
 		CBTConfig::bibleWindow,
@@ -427,7 +427,7 @@ void COptionsDialog::initAccelerators() {
 	);
 
 	// ----- Commentary windows ------ //
-	m_settings.keys.commentary.actionCollection= new KActionCollection(this, "commentaryActions", 0);
+	m_settings.keys.commentary.actionCollection= new TDEActionCollection(this, "commentaryActions", 0);
 	CCommentaryReadWindow::insertKeyboardActions( m_settings.keys.commentary.actionCollection);
 	CBTConfig::setupAccelSettings(
 		CBTConfig::commentaryWindow,
@@ -435,7 +435,7 @@ void COptionsDialog::initAccelerators() {
 	);
 
 	// ----- Lexicon windows ------ //
-	m_settings.keys.lexicon.actionCollection = new KActionCollection(this, "lexiconActions", 0);
+	m_settings.keys.lexicon.actionCollection = new TDEActionCollection(this, "lexiconActions", 0);
 	CLexiconReadWindow::insertKeyboardActions(  m_settings.keys.lexicon.actionCollection );
 	CBTConfig::setupAccelSettings(
 		CBTConfig::lexiconWindow,
@@ -443,7 +443,7 @@ void COptionsDialog::initAccelerators() {
 	);
 
 	// ----- Book windows ------ //
-	m_settings.keys.book.actionCollection= new KActionCollection(this, "bookActions", 0);
+	m_settings.keys.book.actionCollection= new TDEActionCollection(this, "bookActions", 0);
 	CBookReadWindow::insertKeyboardActions( m_settings.keys.book.actionCollection);
 	CBTConfig::setupAccelSettings(
 		CBTConfig::bookWindow,
@@ -829,7 +829,7 @@ void COptionsDialog::saveSword() {
 			moduleDescription = m_settings.swords.standardGreekMorph->currentText();
 			break;
 			default:
-			qWarning("Unhandled module type.");
+			tqWarning("Unhandled module type.");
 		};
 
 		CSwordModuleInfo* const module = backend()->findModuleByDescription(moduleDescription);
@@ -1022,3 +1022,5 @@ void COptionsDialog::slotKeyChooserTypeChanged(const TQString& title) {
 
 	m_settings.keys.keyChooserStack->raiseWidget(t->keyChooser);
 }
+
+#include "coptionsdialog.moc"
