@@ -32,7 +32,7 @@
 
 CKCComboBox::CKCComboBox(bool rw,TQWidget* parent,const char* name)
 : TQComboBox(rw,parent,name) {
-	setFocusPolicy(TQ_WheelFocus);
+	setFocusPolicy(TQWidget::WheelFocus);
 	if (lineEdit()) {
 		installEventFilter( lineEdit() );
 	}
@@ -41,9 +41,9 @@ CKCComboBox::CKCComboBox(bool rw,TQWidget* parent,const char* name)
 /** Reimplementation. */
 bool CKCComboBox::eventFilter( TQObject *o, TQEvent *e ) {
 	if (e->type() == TQEvent::FocusOut) {
-		TQFocusEvent* f = TQT_TQFOCUSEVENT(e);
+		TQFocusEvent* f = static_cast<TQFocusEvent*>(e);
 
-		if (TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(lineEdit()) && f->reason() == TQFocusEvent::Tab) {
+		if (o == lineEdit() && f->reason() == TQFocusEvent::Tab) {
 			int index = listBox()->index( listBox()->findItem(currentText()) );
 			if (index == -1) {
 				index = 0;// return 0 if not found
@@ -64,7 +64,7 @@ bool CKCComboBox::eventFilter( TQObject *o, TQEvent *e ) {
 			emit activated(currentText());
 			return false;
 		}
-		else if (TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(this)) {
+		else if (o == this) {
 			emit activated(currentText());
 			return false;
 		}
@@ -183,12 +183,12 @@ void CKeyChooserWidget::reset(TQStringList *list, int index, bool do_emit) {
 void CKeyChooserWidget::init() {
 	oldKey = TQString();
 
-	setFocusPolicy(TQ_WheelFocus);
+	setFocusPolicy(TQWidget::WheelFocus);
 
 	m_comboBox = new CKCComboBox( true, this );
 	m_comboBox->setAutoCompletion( true );
 	m_comboBox->setInsertionPolicy(TQComboBox::NoInsertion);
-	m_comboBox->setFocusPolicy(TQ_WheelFocus);
+	m_comboBox->setFocusPolicy(TQWidget::WheelFocus);
 
 	m_mainLayout = new TQHBoxLayout( this );
 	m_mainLayout->addWidget(m_comboBox,5);
@@ -200,14 +200,14 @@ void CKeyChooserWidget::init() {
 
 	setTabOrder(m_comboBox, 0);
 
-	connect(m_scroller, TQT_SIGNAL(scroller_pressed()), TQT_SLOT(lock()));
-	connect(m_scroller, TQT_SIGNAL(scroller_released()), TQT_SLOT(unlock()));
-	connect(m_scroller, TQT_SIGNAL(change(int)), TQT_SLOT(changeCombo(int)) );
+	connect(m_scroller, TQ_SIGNAL(scroller_pressed()), TQ_SLOT(lock()));
+	connect(m_scroller, TQ_SIGNAL(scroller_released()), TQ_SLOT(unlock()));
+	connect(m_scroller, TQ_SIGNAL(change(int)), TQ_SLOT(changeCombo(int)) );
 
-	connect(m_comboBox, TQT_SIGNAL(activated(int)), TQT_SLOT(slotComboChanged(int)));
-	//  connect(m_comboBox, TQT_SIGNAL(activated(const TQString&)), TQT_SLOT(slotReturnPressed(const TQString&)));
-	connect(m_comboBox->lineEdit(), TQT_SIGNAL(returnPressed()), TQT_SLOT(slotReturnPressed()));
-	connect(m_comboBox, TQT_SIGNAL(focusOut(int)), TQT_SIGNAL(focusOut(int)));
+	connect(m_comboBox, TQ_SIGNAL(activated(int)), TQ_SLOT(slotComboChanged(int)));
+	//  connect(m_comboBox, TQ_SIGNAL(activated(const TQString&)), TQ_SLOT(slotReturnPressed(const TQString&)));
+	connect(m_comboBox->lineEdit(), TQ_SIGNAL(returnPressed()), TQ_SLOT(slotReturnPressed()));
+	connect(m_comboBox, TQ_SIGNAL(focusOut(int)), TQ_SIGNAL(focusOut(int)));
 
 	updatelock = false;
 	isResetting = false;
