@@ -36,7 +36,7 @@
 #include <tqregexp.h>
 #include <tqmessagebox.h>
 
-//KDE includes
+//TDE includes
 #include <tdeapplication.h>
 #include <tdefiledialog.h>
 #include <tdelocale.h>
@@ -89,15 +89,15 @@ void CSearchAnalysisDialog::initView() {
 	layout->addWidget(button);
 	layout->addSpacing(10);
 
-	m_analysis = new CSearchAnalysis(TQT_TQOBJECT(plainPage()));
+	m_analysis = new CSearchAnalysis(plainPage());
 	m_analysisView = new CSearchAnalysisView(m_analysis, plainPage());
 	m_analysisView->show();
 	layout->addWidget(m_analysisView);
 
-	connect(button, TQT_SIGNAL(clicked()), m_analysis, TQT_SLOT(saveAsHTML()));
+	connect(button, TQ_SIGNAL(clicked()), m_analysis, TQ_SLOT(saveAsHTML()));
 }
 
-/** Initializes the widgets TQT_SIGNAL and TQT_SLOT connections,. */
+/** Initializes the widgets signal and slot connections. */
 void CSearchAnalysisDialog::initConnections() {}
 
 /****************************/
@@ -113,7 +113,7 @@ CSearchAnalysis::CSearchAnalysis(TQObject *parent, const char *name )
 	m_canvasItemList.resize(67);
 	m_canvasItemList.setAutoDelete(true);
 	resize(1,1);
-	connect(this, TQT_SIGNAL(resized()), TQT_SLOT(slotResized()));
+	connect(this, TQ_SIGNAL(resized()), TQ_SLOT(slotResized()));
 }
 
 CSearchAnalysis::~CSearchAnalysis() {}
